#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 commonmark-extensions
version:              0.2.5.6
visibility:           public
id:                   commonmark-extensions-0.2.5.6-C9ehUAj1SnZG6ATq671oxL
key:                  commonmark-extensions-0.2.5.6-C9ehUAj1SnZG6ATq671oxL
license:              BSD-3-Clause
copyright:            2018-2021 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/commonmark-hs
synopsis:             Pure Haskell commonmark parser.
description:
    This library provides some useful extensions to core commonmark
    syntax: smart quotes, definition lists, tables, footnotes, math,
    and more.

category:             Text
abi:                  43004e099aebbd11f0dff7b0f65e4f8b
exposed:              True
exposed-modules:
    Commonmark.Extensions Commonmark.Extensions.Alerts
    Commonmark.Extensions.Attributes
    Commonmark.Extensions.AutoIdentifiers
    Commonmark.Extensions.Autolink Commonmark.Extensions.DefinitionList
    Commonmark.Extensions.Emoji Commonmark.Extensions.FancyList
    Commonmark.Extensions.Footnote Commonmark.Extensions.HardLineBreaks
    Commonmark.Extensions.ImplicitHeadingReferences
    Commonmark.Extensions.Math Commonmark.Extensions.PipeTable
    Commonmark.Extensions.RebaseRelativePaths
    Commonmark.Extensions.Smart Commonmark.Extensions.Strikethrough
    Commonmark.Extensions.Subscript Commonmark.Extensions.Superscript
    Commonmark.Extensions.TaskList Commonmark.Extensions.Wikilinks

import-dirs:          /usr/lib/ghc-9.6.6/site-local/commonmark-extensions-0.2.5.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/commonmark-extensions-0.2.5.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/commonmark-extensions-0.2.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-commonmark-extensions
hs-libraries:         HScommonmark-extensions-0.2.5.6-C9ehUAj1SnZG6ATq671oxL
depends:
    base-4.18.2.1 commonmark-0.2.6.1-LX9IGpSirGpcyBzYOFn3I
    containers-0.6.7 emojis-0.1.5-8CAfGgWzHXT24nYBgeV3n2
    filepath-1.4.300.1 network-uri-2.6.4.2-AAuJwobb8qV67gBUtHYQFB
    parsec-3.1.16.1 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-commonmark-extensions/html/commonmark-extensions.haddock

haddock-html:         /usr/share/doc/haskell-commonmark-extensions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

